# vim: set sw=4 ts=4 et nu:
#
# spec file for package poezio
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           poezio
Version:        0.14
Release:        2.4
Summary:        XMPP Client for the Console
License:        MIT
Group:          Productivity/Networking/Other
URL:            https://poez.io/en/
Source:         https://codeberg.org/poezio/poezio/archive/v%{version}.tar.gz
# PATCH-FIX-OPENSUSE - remove shebangs -- sleep_walker@opensuse.org
Patch0:         poezio-remove_shebang.patch
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  make
BuildRequires:  python-rpm-macros
BuildRequires:  python3-curses
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
Requires:       python3-aiodns
Requires:       python3-curses
Requires:       python3-pyasn1-modules
Requires:       python3-setuptools
Requires:       python3-slixmpp

%description
Poezio is a console-based client for XMPP, the protocol on which the
Jabber IM network is built. The network can be conneced to without
having to create an account and join various chatrooms immediately.
The client tries to look similar to the weechat/irssi IRC clients and
many commands are identical. Configuration can be done in a
configuration file or directly from the client.

%package doc
Summary:        Documentation for poezio
Group:          Productivity/Networking/Other
BuildArch:      noarch

%description doc
Documentation generated by the poezio package, but split out due to size.

%prep
%autosetup -p1 -n %{name}

%build
%python3_build

%install
%python3_install
install -m 0755 -d %{buildroot}%{_docdir}/%{name}
mv %{buildroot}%{_docdir}/../%{name} %{buildroot}%{_docdir}/
install -m 0755 -d %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/io.poez.Poezio.svg
install -m 0644 data/poezio_logo.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/io.poez.Poezio.svg
%fdupes %{buildroot}%{_libdir}/python3*/site-packages
%fdupes %{buildroot}%{_docdir}/%{name}

%files doc
%doc README.rst
%{_docdir}/poezio

%files
%license COPYING
%{_libdir}/python3*/site-packages/%{name}*
%{_bindir}/poezio*
%{_datadir}/poezio
%{_mandir}/man1/%{name}*%{ext_man}
%{_datadir}/applications/io.poez.Poezio.desktop
%{_datadir}/metainfo/io.poez.Poezio.appdata.xml
%{_datadir}/icons/hicolor/scalable/apps/io.poez.Poezio.svg

%changelog
* Wed Feb 21 2024 Michael Vetter <mvetter@suse.com>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
- Update source URL
* Tue Dec  6 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.14:
  Configuration changes:
  * ADDED: `mam_sync`, `mam_sync_limit`.
  * ADDED: `autocolor_tab_names`.
  * CHANGED: `ca_cert_path` is commented out. Poezio will attempt to guess
    common CA bundle paths. The option can be used to overwrite this behaviour.
  * REMOVED: `force_remote_bookmarks`.
  * REMOVED: options related to activity, mood, gaming, tune:
    `enable_user_activity`, `enable_user_mood`, `enable_user_gaming`,
    `enable_user_tune`, `display_activity_notifications`,
    `display_mood_notifications`, `display_gaming_notifications`,
    `display_tune_notifications`.
  * REMOVED: `deterministic_muc_colors`.
  Changes:
  * DEPRECATION: /leave is deprecated. Use /part or /close instead.
  * REMOVED: rich presence (activity, mood, gaming, tune) from poezio, alongside
    with configuration options and commands: /activity, /mood,
    and /gaming. These are moved to the new user_extras plugin.
  * REMOVED: non-deterministic nick colors in MUC.
  * REMOVED: XEP-0319 support removed for privacy and performance.
  * REMOVED: Support for pypy3 with the removal of poopt.py
  * ADDED: New /request_voice command for moderated rooms
  * ADDED: /join: support using an XMPP URI (xmpp:...?join)
  * ADDED: /destroy_room: new optional reason and altroom arguments
  * ADDED: Newlines now considered as word separator in input manipulation (#3411)
  * ADDED: Colored tab names or number using Consistent Color Generation behind
    `autocolor_tab_names` (thanks jonas!)
  * Stop highlighting on MUC history messages just because they're delayed
  * Stop displaying the traceback in debug log when /xhtml fails
  * Ensure launch.sh can be use outside the repository (Thanks kaliko)
  * Detect `/set option = value` pattern and do as it `/set option value` was
    called. (#3517)
  * Newlines taken into account on completion (#3385)
  * Allow resizing certificate confirmation window (#3371)
  * Make theming more configurable around nicks
  * Log MUC <destroy/> payload in the information buffer
  * impromptu: wait for room subject before configuring and inviting
  * Impromptu: rooms now have pronouceable short names
  * impromptu: ensure a room is empty before joining
  * impromptu: now uses mediated invites
  * Fetch from MAM by default when use_log is False.
  * xhtml: Add a new line after a blockquote
  Bug fixes:
  * Ensure bookmark is present before removing it in /close.
  * Ensure bookmarks are saved correctly on method config change, and on /close.
  * Ensure nick is added to bookmark when specified
  * Do not crash on bookmark without a nickname (Thanks Ge0rG)
  * Ensure the correct tab is bookmarked on /bookmark and /join
  * /bookmark: treat empty nick as no nick to avoid failing on empty resource
  * Fix closing a tab not in bookmarks
  * Disco barejid instead of domains on sent carbons. Follow-up of 5e40437.
  * Only use JID internally when handling affiliations. Add nick if present.  (#3536)
  * /last_activity: prevent traceback
  * Fix bad error handling when checking bookmarks storage
  * `/join / password` works again
  * Report available presence in tabs correctly
  * /display_correction: now reports the correct time for private messages (#3532)
  * Fix composing indicators not showing (#3527)
  * Fix pasting text in data forms and bookmarkstab (#3519)
  * Fix /me logging (#3432)
  * Retrieve nick colors from the correct section
  * Do not scroll right by default in dataforms/bookmark text
  * Hack around the time limit for topic messages
  * Ensure MUC-PM logging filenames are generated as expected (Thanks Ge0rG, southerntofu)
  * Fix poezio displaying many times the same participant in the user list.
  * Fix default dataform field handling (#3554)
  * Fix MUCListTab not joining selected MUCs (#3553)
  * Fix /color completion (Thanks eijebong)
  * /info: Don't display comma before status message if not available
  Plugins:
  * ADDED: untrackme plugin. based on remove_get_trackers.
  * ADDED: user_extras plugin. /activity, /mood and /gaming moved from core.
  * ADDED: sticker plugin.
  * DEPRECATED: remove_get_trackers
  * REMOVED: /irc_login from the irc plugin.
  * Reorder: Prevent GapTabs from being serialized and ignore when serialized as
    they're recreated automatically.
  * Code: prevent traceback when not enough arguments
  * Link: Add support for aesgcm, gemini and gopher URIs
  * Contact: iterate all data forms (Thanks Ge0rG)
  * Fix plugins (embed, lastlog, otr, quote, time_marker) to use poezio.ui.types
  * Disco: Added error handling
  * IRC: Fix the plugin to work with the various refactors, and use
    irc.jabberfr.org as a default gateway
  API:
  * BREAKING: E2EEPlugin.decrypt's `tab` parameter is now of type
    Optional[ChatTab] instead of ChatTab.
  * BREAKING: E2EEPlugin.supported_tab_types is now required
  * BREAKING: decrypt method is now async
  * E2EEPlugin decrypts encrypted messages even when they have no body.
  * E2EEPlugin lets through already encrypted messages without giving them
    to the user lib (poezio-omemo, for example).
  * Correctly pass realjid to decrypt call for MUC messages
  * /<encryption_name>_fingerprint command is added. Plugins can implement
    `get_fingerprints` and `format_fingerprint` for it to return a (formatted)
    value.
  Under the hood:
  * Moved development from 'master' to 'main' branch
  * Lots of type hints added (decorators, multiuserchat, shlex, common, muctab,
    etc.) fixing many bugs
  * Lots of event handlers and calls are now async in poezio. Many callbacks removed.
  * Lots of refactoring
  * Performance improvements:
  - Trim all messages by 24 bytes on 64-bit systems
  - Reduce log parsing by a lot
  * No more safeJID calls. (#3457)
  * Rework some features to use slixmpp's API instead of custom poezio code
    (i.e., muc's set_subject, set_role, set_affiliation, destroy_room,
    cancel_config, set_room_config, and most events)
  * Split commands from Core
  * Require typing_extensions package for python
  * Require setuptools package explicitly because of pkg_resources' import
  * Replace asyncio.ensure_future with asyncio.create_task
- Update URL from http://poezio.eu/en/ to https://poez.io/en/
* Wed Dec  8 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Install upstream desktop file with logo to fix build on Leap
* Mon Aug 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.13.1:
  - Contacts won’t be seen playing games or music when they actually stop doing
    so.
  - /leave now toggles off the autojoin flag instead of removing the bookmark.
  - Only add auotjoin on new bookmarks for synchronise_open_rooms on /join
  - /affiliation displays things in the info win instead of directly in the room,
    and additionally displays which room it refers to.
  - List the correct required versions for package maintainers.
  - Fix the AppStream manifest to get Flathub to accept it.
  - Add a warning when the terminal doesn’t support 256color mode.
  - Display our own nick properly in messages received from MAM.
  - Only send an unavailable presence on closing a room if we are joined.
  - Don’t display the current date for history messages received today.
  - Fix marquee and dice plugin to use newer Last Message Correction format.
  - Bookmarks tab properly displays bookmarks method (local/remote) and allows
    to switch between them again.
  - Updated manpages and added manpages built from the doc in the setup process.
    Packagers need to run setup.py build_man to have them built.
* Tue Mar 24 2020 Tomas Cech <sleep_walker@opensuse.org>
- add python3-pyasn1-modules as run-time dependency (fixes bnc#1167427)
- bump to 0.12.1 (fixes bnc#1167427)
  - Fix compatibility with the Python 3.5 in debian stable
  - Require Python 3.5, to add support for Python 3.7, use proper async
    functions, use typing, italics formatting, FIXME
  - Added support for XEP-0392 (Consistent Color Generation)
  - Added support for XEP-0153 (vCard-Based Avatars) and XEP-0084 (User
    Avatar) in the roster tab
  - Added support for XEP-0363 (HTTP File Upload) for easy file transfer,
    in the upload plugin with /upload
  - Added support for XEP-0066 (Out of Band Data) for Conversations
    compatibility when sharing images, in the embed plugin with /embed
  - Removed support for XEP-0296 (Best Practices for Resource Locking),
    to use all features available no matter what our contact’s current
    clients support
  - Check for usable Unicode support on start
  - Generate a device id on first start, and use it for our resource
  - Display the public key hash instead of the certificate’s
  - Handle carbons properly for private messages in rooms
  - /bookmarks can now be used to rename tabs as you want
  - Remove unexpected command completion based on command prefix
  - Add an irssi theme
  - Add a code plugin, which requires pygments
  - Fix resource duplication on reconnect
  - Misc fixes and improvements
* Sun Mar  4 2018 jengelh@inai.de
- Remove filler wording from description.
* Sun Mar  4 2018 sleep_walker@opensuse.org
- fix package license and add license file to the package
- run through spec cleaner
- add poezio-remove_shebang.patch
- add README.rst to the package
* Thu Feb  8 2018 sleep_walker@opensuse.org
- bump to 0.11
  see CHANGELOG for full list of changes (which happened over 7 years)
- requires python3-aiodns now, requires python-slixmpp instead of
  python-sleakxmpp
- split documentation
* Wed Feb  2 2011 pascal.bleser@opensuse.org
- initial version (0.7.1)
